=== modified file 'drizzled/security_context.h'
--- drizzled/security_context.h	2010-03-18 18:07:58 +0000
+++ drizzled/security_context.h	2010-10-16 11:09:48 +0000
@@ -58,7 +58,7 @@
     return user;
   }
 
-  void setUser(const char *newuser)
+  void setUser(const std::string &newuser)
   {
     user.assign(newuser);
   }

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-10-15 05:30:39 +0000
+++ drizzled/session.cc	2010-10-16 11:09:48 +0000
@@ -626,9 +626,9 @@
   return true;
 }
 
-bool Session::checkUser(const char *passwd, uint32_t passwd_len, const char *in_db)
+bool Session::checkUser(const std::string &passwd_str,
+                        const std::string &in_db)
 {
-  const string passwd_str(passwd, passwd_len);
   bool is_authenticated=
     plugin::Authentication::isAuthenticated(getSecurityContext(),
                                             passwd_str);
@@ -641,7 +641,7 @@
   }
 
   /* Change database if necessary */
-  if (in_db && in_db[0])
+  if (not in_db.empty())
   {
     SchemaIdentifier identifier(in_db);
     if (mysql_change_db(this, identifier))
@@ -651,7 +651,7 @@
     }
   }
   my_ok();
-  password= test(passwd_len);          // remember for error messages
+  password= not passwd_str.empty();
 
   /* Ready to handle queries */
   return true;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-10-15 05:30:39 +0000
+++ drizzled/session.h	2010-10-16 11:09:48 +0000
@@ -1215,7 +1215,7 @@
    * @param  Length of scrambled password
    * @param  Database name to connect to, may be NULL
    */
-  bool checkUser(const char *passwd, uint32_t passwd_len, const char *db);
+  bool checkUser(const std::string &passwd, const std::string &db);
   
   /**
    * Returns the timestamp (in microseconds) of when the Session 

=== modified file 'drizzled/set_var.h'
--- drizzled/set_var.h	2010-10-15 17:18:02 +0000
+++ drizzled/set_var.h	2010-10-16 11:09:48 +0000
@@ -372,6 +372,76 @@
   bool is_readonly() const { return true; }
 };
 
+class sys_var_const_string :
+  public sys_var
+{
+  const std::string &value;
+public:
+  sys_var_const_string(const char *name_arg,
+                       const std::string& value_arg) :
+    sys_var(name_arg),
+    value(value_arg)
+  { }
+
+  inline void set(char *)
+  { }
+
+  bool check(Session *, set_var *)
+  {
+    return true;
+  }
+  bool update(Session *, set_var *)
+  {
+    return true;
+  }
+  SHOW_TYPE show_type() { return SHOW_CHAR; }
+  unsigned char *value_ptr(Session *, sql_var_t, const LEX_STRING *)
+  {
+    return (unsigned char*)(value.c_str());
+  }
+  bool check_update_type(Item_result)
+  {
+    return true;
+  }
+  bool check_default(sql_var_t) { return true; }
+  bool is_readonly() const { return true; }
+};
+
+class sys_var_const_string_val :
+  public sys_var
+{
+  const std::string value;
+public:
+  sys_var_const_string_val(const char *name_arg,
+                           const std::string& value_arg) :
+    sys_var(name_arg),
+    value(value_arg)
+  { }
+
+  inline void set(char *)
+  { }
+
+  bool check(Session *, set_var *)
+  {
+    return true;
+  }
+  bool update(Session *, set_var *)
+  {
+    return true;
+  }
+  SHOW_TYPE show_type() { return SHOW_CHAR; }
+  unsigned char *value_ptr(Session *, sql_var_t, const LEX_STRING *)
+  {
+    return (unsigned char*)(value.c_str());
+  }
+  bool check_update_type(Item_result)
+  {
+    return true;
+  }
+  bool check_default(sql_var_t) { return true; }
+  bool is_readonly() const { return true; }
+};
+
 class sys_var_const_str :public sys_var
 {
   char *value;					// Pointer to const value

=== modified file 'plugin/console/console.cc'
--- plugin/console/console.cc	2010-10-15 18:57:13 +0000
+++ plugin/console/console.cc	2010-10-16 11:09:48 +0000
@@ -31,9 +31,6 @@
 
 static bool enabled= false;
 static bool debug_enabled= false;
-static char* username= NULL;
-static char* password= NULL;
-static char* db= NULL;
 
 
 class ClientConsole: public plugin::Client
@@ -41,12 +38,20 @@
   bool is_dead;
   uint32_t column;
   uint32_t max_column;
+  const std::string &username;
+  const std::string &password;
+  const std::string &db;
 
 public:
-  ClientConsole():
+  ClientConsole(const std::string &username_arg,
+                const std::string &password_arg,
+                const std::string &db_arg) :
     is_dead(false),
     column(0),
-    max_column(0)
+    max_column(0),
+    username(username_arg),
+    password(password_arg),
+    db(db_arg)
   {}
 
   virtual void printDebug(const char *message)
@@ -95,7 +100,7 @@
   {
     printDebug("authenticate");
     session->getSecurityContext().setUser(username);
-    return session->checkUser(password, strlen(password), db);
+    return session->checkUser(password, db);
   }
 
   virtual bool readCommand(char **packet, uint32_t *packet_length)
@@ -269,10 +274,19 @@
 class ListenConsole: public plugin::Listen
 {
   int pipe_fds[2];
+  const std::string username;
+  const std::string password;
+  const std::string db;
 
 public:
-  ListenConsole(const std::string &name_arg) :
-    plugin::Listen(name_arg)
+  ListenConsole(const std::string &name_arg,
+                const std::string &username_arg,
+                const std::string &password_arg,
+                const std::string &db_arg) :
+    plugin::Listen(name_arg),
+    username(username_arg),
+    password(password_arg),
+    db(db_arg)
   {
     pipe_fds[0]= -1;
   }
@@ -284,11 +298,6 @@
       close(pipe_fds[0]);
       close(pipe_fds[1]);
     }
-
-    /* Cleanup from the module strdup'ing these below */
-    free(username);
-    free(password);
-    free(db);
   }
 
   virtual bool getFileDescriptors(std::vector<int> &fds)
@@ -314,36 +323,22 @@
   {
     char buffer[1];
     assert(read(fd, buffer, 1) == 1);
-    return new ClientConsole;
+    return new ClientConsole(username, password, db);
   }
 };
 
 static int init(drizzled::module::Context &context)
 {
   const module::option_map &vm= context.getOptions();
-  /* duplicating these here means they need to be freed. They're global, so
-     we'll just have the ListenConsole object do it in its destructor */
-  if (vm.count("username"))
-    username= strdup(vm["username"].as<string>().c_str());
-  else
-    username= strdup("");
-
-  if (vm.count("password"))
-    password= strdup(vm["password"].as<string>().c_str());
-  else
-    password= strdup("");
-
-  if (vm.count("db"))
-    db= strdup(vm["db"].as<string>().c_str());
-  else
-    db= strdup("");
-
-  context.add(new ListenConsole("console"));
+  const string username(vm.count("username") ? vm["username"].as<string>() : "");
+  const string password(vm.count("password") ? vm["password"].as<string>() : "");
+  const string db(vm.count("db") ? vm["db"].as<string>() : "");
   context.registerVariable(new sys_var_bool_ptr("enable", &enabled));
   context.registerVariable(new sys_var_bool_ptr("debug_enable", &debug_enabled));
-  context.registerVariable(new sys_var_const_str("username", username));
-  context.registerVariable(new sys_var_const_str("password", password));
-  context.registerVariable(new sys_var_const_str("db", db));
+  context.registerVariable(new sys_var_const_string_val("username", username));
+  context.registerVariable(new sys_var_const_string_val("password", password));
+  context.registerVariable(new sys_var_const_string_val("db", db));
+  context.add(new ListenConsole("console", username, password, db));
   return 0;
 }
 

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2010-10-02 21:15:42 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2010-10-16 11:09:48 +0000
@@ -787,7 +787,7 @@
 
   session->getSecurityContext().setUser(user);
 
-  return session->checkUser(passwd, passwd_len, l_db);
+  return session->checkUser(string(passwd, passwd_len), l_db);
 }
 
 bool ClientMySQLProtocol::netStoreData(const unsigned char *from, size_t length)

